package org.example.SastaTicketPage;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.openqa.selenium.By;
import org.openqa.selenium.NoSuchElementException;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;

public class SastaTicketPage {

    private static final Logger log = LogManager.getLogger(SastaTicketPage.class);
    private WebDriver driver;

    public SastaTicketPage(WebDriver driver) {
        this.driver = driver;
    }

    // Open homepage
    public void openHomePage() {
        log.info("Opening SastaTicket homepage.");
        driver.get("https://www.sastaticket.pk/");
        log.info("SastaTicket homepage opened successfully.");
    }

    // Correct locator for search field (info), forced error in error logging for testing
    public void IClickOnSearchField() {
        String correctLocator = "//span[@title='Lahore (LHE)']"; // Correct locator
        String incorrectLocator = "//span[@title='NonExistentElement']"; // Forced incorrect locator for error logging

        try {
            // Attempt to interact with the element using the correct locator
            log.info("Clicking on search field with correct locator: " + correctLocator);
            WebElement searchField = driver.findElement(By.xpath(correctLocator));
            searchField.click();
            log.info("Search field clicked successfully.");

            // Simulate error condition intentionally for testing
            log.info("Simulating error for testing purposes...");
            WebElement fakeElement = driver.findElement(By.xpath(incorrectLocator)); // This will trigger an exception
            fakeElement.click(); // This line will not be reached
        } catch (NoSuchElementException e) {
            // Log an error when the forced wrong locator causes an exception
            log.error("Error: Could not find search field with locator: " + incorrectLocator);
        }
    }

    // Correct locator for destination field (info), forced error in error logging for testing
    public void IClickOnSearchFieldDestination() {
        String correctLocator = "//input[@id='rc_select_1']"; // Correct locator
        String incorrectLocator = "//input[@id='NonExistentInput']"; // Forced incorrect locator for error logging

        try {
            log.info("Clicking on destination field with correct locator: " + correctLocator);
            WebElement destinationField = driver.findElement(By.xpath(correctLocator));
            destinationField.click();
            log.info("Destination field clicked successfully.");

            // Simulate error condition intentionally for testing
            log.info("Simulating error for testing purposes...");
            WebElement fakeElement = driver.findElement(By.xpath(incorrectLocator)); // This will trigger an exception
            fakeElement.click(); // This line will not be reached
        } catch (NoSuchElementException e) {
            log.error("Error: Could not find destination field with locator: " + incorrectLocator);
        }
    }

    // Correct locator for destination city selection, only run error if an exception is caught
    public void selectDestinationCity() {
        String correctLocator = "//h5[normalize-space()='Karachi, Pakistan (KHI)']"; // Correct locator
        String incorrectLocator = "//h5[normalize-space()='NonExistentCity']"; // Forced incorrect locator for error logging

        try {
            log.info("Selecting destination city with correct locator: " + correctLocator);
            WebElement destinationCity = driver.findElement(By.xpath(correctLocator));
            destinationCity.click();
            log.info("Destination city selected successfully.");

            // Simulate error condition intentionally for testing
            log.info("Simulating error for testing purposes...");
            WebElement fakeElement = driver.findElement(By.xpath(incorrectLocator)); // This will trigger an exception
            fakeElement.click(); // This line will not be reached
        } catch (NoSuchElementException e) {
            log.error("Error: Could not find destination city with locator: " + incorrectLocator);
        }
    }

    // Correct locator for date selection, only run error if an exception is caught
    public void clickDate() {
        String correctLocator = "//div[@class='ant-col _3xTiXZL3weCRW_cW7BB1TW j18oDGKsHFCUVl6dCIeWr']//div[@class='bMmOjUs6T-Jm0Z_w3DUKj']"; // Correct locator
        String incorrectLocator = "//div[@class='NonExistentDate']"; // Forced incorrect locator for error logging

        try {
            log.info("Clicking on date field with correct locator: " + correctLocator);
            WebElement date = driver.findElement(By.xpath(correctLocator));
            date.click();
            log.info("Date field clicked successfully.");

            // Simulate error condition intentionally for testing
            log.info("Simulating error for testing purposes...");
            WebElement fakeElement = driver.findElement(By.xpath(incorrectLocator)); // This will trigger an exception
            fakeElement.click(); // This line will not be reached
        } catch (NoSuchElementException e) {
            log.error("Error: Could not find date field with locator: " + incorrectLocator);
        }
    }

    // Correct locator for search flight button, only run error if an exception is caught
    public void clickSearchFlight() {
        String correctLocator = "//span[normalize-space()='Search Flights']"; // Correct locator
        String incorrectLocator = "//span[normalize-space()='NonExistentSearchButton']"; // Forced incorrect locator for error logging

        try {
            log.info("Clicking on search flight button with correct locator: " + correctLocator);
            WebElement searchFlightButton = driver.findElement(By.xpath(correctLocator));
            searchFlightButton.click();
            log.info("Search flight button clicked successfully.");

            // Simulate error condition intentionally for testing
            log.info("Simulating error for testing purposes...");
            WebElement fakeElement = driver.findElement(By.xpath(incorrectLocator)); // This will trigger an exception
            fakeElement.click(); // This line will not be reached
        } catch (NoSuchElementException e) {
            log.error("Error: Could not find search flight button with locator: " + incorrectLocator);
        }
    }
}
